<?php return array(
    'root' => array(
        'name' => 'joomla/joomla-cms',
        'pretty_version' => 'dev-6.2-dev',
        'version' => 'dev-6.2-dev',
        'reference' => '2882bddfe1744bc8c74786d565f2cd2ef93de679',
        'type' => 'project',
        'install_path' => __DIR__ . '/../../../',
        'aliases' => array(),
        'dev' => false,
    ),
    'versions' => array(
        'algo26-matthias/idna-convert' => array(
            'pretty_version' => 'v4.2.1',
            'version' => '4.2.1.0',
            'reference' => '87bfcab8e453d7ede78eeec15d75c75f0e926f3c',
            'type' => 'library',
            'install_path' => __DIR__ . '/../algo26-matthias/idna-convert',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'altcha-org/altcha' => array(
            'pretty_version' => 'v1.3.3',
            'version' => '1.3.3.0',
            'reference' => '9a9b98c48dea0b2e8c353ea991d5f5627cbdab36',
            'type' => 'library',
            'install_path' => __DIR__ . '/../altcha-org/altcha',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'brick/math' => array(
            'pretty_version' => '0.12.3',
            'version' => '0.12.3.0',
            'reference' => '866551da34e9a618e64a819ee1e01c20d8a588ba',
            'type' => 'library',
            'install_path' => __DIR__ . '/../brick/math',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'composer/ca-bundle' => array(
            'pretty_version' => '1.5.12',
            'version' => '1.5.12.0',
            'reference' => '00a2f4201641d5c53f7fc0195e6c8d9fcc321a78',
            'type' => 'library',
            'install_path' => __DIR__ . '/./ca-bundle',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'defuse/php-encryption' => array(
            'pretty_version' => 'v2.4.0',
            'version' => '2.4.0.0',
            'reference' => 'f53396c2d34225064647a05ca76c1da9d99e5828',
            'type' => 'library',
            'install_path' => __DIR__ . '/../defuse/php-encryption',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'doctrine/inflector' => array(
            'pretty_version' => '2.1.0',
            'version' => '2.1.0.0',
            'reference' => '6d6c96277ea252fc1304627204c3d5e6e15faa3b',
            'type' => 'library',
            'install_path' => __DIR__ . '/../doctrine/inflector',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'dragonmantank/cron-expression' => array(
            'pretty_version' => 'v3.6.0',
            'version' => '3.6.0.0',
            'reference' => 'd61a8a9604ec1f8c3d150d09db6ce98b32675013',
            'type' => 'library',
            'install_path' => __DIR__ . '/../dragonmantank/cron-expression',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'enshrined/svg-sanitize' => array(
            'pretty_version' => '0.22.0',
            'version' => '0.22.0.0',
            'reference' => '0afa95ea74be155a7bcd6c6fb60c276c39984500',
            'type' => 'library',
            'install_path' => __DIR__ . '/../enshrined/svg-sanitize',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'fig/link-util' => array(
            'pretty_version' => '1.2.0',
            'version' => '1.2.0.0',
            'reference' => '10e52348a2e9ad4581f2bf3e16458f0861a88c6a',
            'type' => 'library',
            'install_path' => __DIR__ . '/../fig/link-util',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'google/recaptcha' => array(
            'pretty_version' => '1.3.1',
            'version' => '1.3.1.0',
            'reference' => '56522c261d2e8c58ba416c90f81a4cd9f2ed89b9',
            'type' => 'library',
            'install_path' => __DIR__ . '/../google/recaptcha',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'guzzlehttp/promises' => array(
            'pretty_version' => '2.5.0',
            'version' => '2.5.0.0',
            'reference' => '4360e982f87f5f258bf872d094647791db2f4c8e',
            'type' => 'library',
            'install_path' => __DIR__ . '/../guzzlehttp/promises',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'guzzlehttp/psr7' => array(
            'pretty_version' => '2.12.1',
            'version' => '2.12.1.0',
            'reference' => '172ef2f4e9824c1e058b7f30be8ae25a02c0f2b7',
            'type' => 'library',
            'install_path' => __DIR__ . '/../guzzlehttp/psr7',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'jakeasmith/http_build_url' => array(
            'pretty_version' => '1.0.1',
            'version' => '1.0.1.0',
            'reference' => '93c273e77cb1edead0cf8bcf8cd2003428e74e37',
            'type' => 'library',
            'install_path' => __DIR__ . '/../jakeasmith/http_build_url',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'jfcherng/php-color-output' => array(
            'pretty_version' => '3.0.0',
            'version' => '3.0.0.0',
            'reference' => '6c7bf16686cc6a291647fcb87491640a2d5edd20',
            'type' => 'library',
            'install_path' => __DIR__ . '/../jfcherng/php-color-output',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'jfcherng/php-diff' => array(
            'pretty_version' => '6.16.2',
            'version' => '6.16.2.0',
            'reference' => '7f46bcfc582e81769237d0b3f6b8a548efe8799d',
            'type' => 'library',
            'install_path' => __DIR__ . '/../jfcherng/php-diff',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'jfcherng/php-mb-string' => array(
            'pretty_version' => '2.0.1',
            'version' => '2.0.1.0',
            'reference' => '8407bfefde47849c9e7c9594e6de2ac85a0f845d',
            'type' => 'library',
            'install_path' => __DIR__ . '/../jfcherng/php-mb-string',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'jfcherng/php-sequence-matcher' => array(
            'pretty_version' => '4.0.3',
            'version' => '4.0.3.0',
            'reference' => 'd2038ac29627340a7458609072a8ba355e80ec5b',
            'type' => 'library',
            'install_path' => __DIR__ . '/../jfcherng/php-sequence-matcher',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'joomla/application' => array(
            'pretty_version' => '4.0.0',
            'version' => '4.0.0.0',
            'reference' => '878d1f4a2dc03b6197d0e6cfb4a969ec06a3314d',
            'type' => 'library',
            'install_path' => __DIR__ . '/../joomla/application',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'joomla/archive' => array(
            'pretty_version' => '4.0.0',
            'version' => '4.0.0.0',
            'reference' => '7a8d0eda637bd37bc3de744aa3e4ce516d4356b0',
            'type' => 'joomla-package',
            'install_path' => __DIR__ . '/../joomla/archive',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'joomla/authentication' => array(
            'pretty_version' => '4.0.0',
            'version' => '4.0.0.0',
            'reference' => '1d9b946410ac43c8d206d9d6bf741173b83a8e4c',
            'type' => 'joomla-package',
            'install_path' => __DIR__ . '/../joomla/authentication',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'joomla/console' => array(
            'pretty_version' => '4.0.0',
            'version' => '4.0.0.0',
            'reference' => 'b58fb572436ad9e230061ff6929aa1446849efe8',
            'type' => 'joomla-package',
            'install_path' => __DIR__ . '/../joomla/console',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'joomla/crypt' => array(
            'pretty_version' => '4.0.0',
            'version' => '4.0.0.0',
            'reference' => '9b069827a7875ae3bff409695624071f4d356aca',
            'type' => 'joomla-package',
            'install_path' => __DIR__ . '/../joomla/crypt',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'joomla/data' => array(
            'pretty_version' => '4.0.0',
            'version' => '4.0.0.0',
            'reference' => 'e00293048e893dc3c5e793b091e87da84faf3963',
            'type' => 'joomla-package',
            'install_path' => __DIR__ . '/../joomla/data',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'joomla/database' => array(
            'pretty_version' => '4.0.0',
            'version' => '4.0.0.0',
            'reference' => '2e744e7959368891fe52ccb35790e201251f6f39',
            'type' => 'joomla-package',
            'install_path' => __DIR__ . '/../joomla/database',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'joomla/di' => array(
            'pretty_version' => '4.0.0',
            'version' => '4.0.0.0',
            'reference' => 'e8511111e2b5b239f75116f9ff75b43c18809868',
            'type' => 'joomla-package',
            'install_path' => __DIR__ . '/../joomla/di',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'joomla/event' => array(
            'pretty_version' => '4.0.0',
            'version' => '4.0.0.0',
            'reference' => '4bbbfb0a3444cb3e3f9abd57d623caa06e9207b5',
            'type' => 'joomla-package',
            'install_path' => __DIR__ . '/../joomla/event',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'joomla/filesystem' => array(
            'pretty_version' => '4.2.0',
            'version' => '4.2.0.0',
            'reference' => '66e6212d4cb4d36e7dd5a01a94c5f257e3026a52',
            'type' => 'joomla-package',
            'install_path' => __DIR__ . '/../joomla/filesystem',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'joomla/filter' => array(
            'pretty_version' => '4.0.2',
            'version' => '4.0.2.0',
            'reference' => 'c7bdd35af5bee9dd4bdf2674f483eff44ef28065',
            'type' => 'joomla-package',
            'install_path' => __DIR__ . '/../joomla/filter',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'joomla/http' => array(
            'pretty_version' => '4.0.2',
            'version' => '4.0.2.0',
            'reference' => '3c494722385f556e022ea57b9e9c7474d95452c3',
            'type' => 'joomla-package',
            'install_path' => __DIR__ . '/../joomla/http',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'joomla/input' => array(
            'pretty_version' => '4.0.0',
            'version' => '4.0.0.0',
            'reference' => 'f366f97b143bd9d15f57dad74b21f72ac99d89ec',
            'type' => 'joomla-package',
            'install_path' => __DIR__ . '/../joomla/input',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'joomla/joomla-cms' => array(
            'pretty_version' => 'dev-6.2-dev',
            'version' => 'dev-6.2-dev',
            'reference' => '2882bddfe1744bc8c74786d565f2cd2ef93de679',
            'type' => 'project',
            'install_path' => __DIR__ . '/../../../',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'joomla/language' => array(
            'pretty_version' => '4.0.0',
            'version' => '4.0.0.0',
            'reference' => '371507d84103e9e7b48253e72b3bcc8d91cf5a63',
            'type' => 'joomla-package',
            'install_path' => __DIR__ . '/../joomla/language',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'joomla/oauth1' => array(
            'pretty_version' => '4.0.1',
            'version' => '4.0.1.0',
            'reference' => 'e48c0af2173222494cbac414e971c807f32a9eb9',
            'type' => 'joomla-package',
            'install_path' => __DIR__ . '/../joomla/oauth1',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'joomla/oauth2' => array(
            'pretty_version' => '4.0.2',
            'version' => '4.0.2.0',
            'reference' => 'bb24c0a969fcc62c97997ba33a476ec888c34b00',
            'type' => 'joomla-package',
            'install_path' => __DIR__ . '/../joomla/oauth2',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'joomla/registry' => array(
            'pretty_version' => '4.0.0',
            'version' => '4.0.0.0',
            'reference' => '5692d8423c9b568627df701e9fd505eae5ea8f72',
            'type' => 'joomla-package',
            'install_path' => __DIR__ . '/../joomla/registry',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'joomla/router' => array(
            'pretty_version' => '4.0.0',
            'version' => '4.0.0.0',
            'reference' => 'd0552ac09b92712a140fff2323579b84fbaa12b8',
            'type' => 'joomla-package',
            'install_path' => __DIR__ . '/../joomla/router',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'joomla/session' => array(
            'pretty_version' => '4.0.0',
            'version' => '4.0.0.0',
            'reference' => '3d1d8bc093d659053c46eec4962bef4c1e9e0206',
            'type' => 'joomla-package',
            'install_path' => __DIR__ . '/../joomla/session',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'joomla/string' => array(
            'pretty_version' => '4.0.0',
            'version' => '4.0.0.0',
            'reference' => 'da2329e05f1f5fc98b709f8638f279513bcd1108',
            'type' => 'joomla-package',
            'install_path' => __DIR__ . '/../joomla/string',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'joomla/uri' => array(
            'pretty_version' => '4.0.0',
            'version' => '4.0.0.0',
            'reference' => '9fa4fac811bf63e830d46d83031c353cf2765bcd',
            'type' => 'joomla-package',
            'install_path' => __DIR__ . '/../joomla/uri',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'joomla/utilities' => array(
            'pretty_version' => '4.0.0',
            'version' => '4.0.0.0',
            'reference' => '5f234527f7dad7111830b091aef52787c3c07cc8',
            'type' => 'joomla-package',
            'install_path' => __DIR__ . '/../joomla/utilities',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'laminas/laminas-diactoros' => array(
            'pretty_version' => '3.8.0',
            'version' => '3.8.0.0',
            'reference' => '60c182916b2749480895601649563970f3f12ec4',
            'type' => 'library',
            'install_path' => __DIR__ . '/../laminas/laminas-diactoros',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'lcobucci/clock' => array(
            'pretty_version' => '3.5.0',
            'version' => '3.5.0.0',
            'reference' => 'a3139d9e97d47826f27e6a17bb63f13621f86058',
            'type' => 'library',
            'install_path' => __DIR__ . '/../lcobucci/clock',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'lcobucci/jwt' => array(
            'pretty_version' => '4.3.0',
            'version' => '4.3.0.0',
            'reference' => '4d7de2fe0d51a96418c0d04004986e410e87f6b4',
            'type' => 'library',
            'install_path' => __DIR__ . '/../lcobucci/jwt',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'maximebf/debugbar' => array(
            'dev_requirement' => false,
            'replaced' => array(
                0 => 'v2.2.6',
            ),
        ),
        'mtdowling/cron-expression' => array(
            'dev_requirement' => false,
            'replaced' => array(
                0 => '^1.0',
            ),
        ),
        'paragonie/constant_time_encoding' => array(
            'pretty_version' => 'v2.8.2',
            'version' => '2.8.2.0',
            'reference' => 'e30811f7bc69e4b5b6d5783e712c06c8eabf0226',
            'type' => 'library',
            'install_path' => __DIR__ . '/../paragonie/constant_time_encoding',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'paragonie/random_compat' => array(
            'dev_requirement' => false,
            'replaced' => array(
                0 => '9.99.99',
            ),
        ),
        'paragonie/sodium_compat' => array(
            'pretty_version' => 'v1.24.0',
            'version' => '1.24.0.0',
            'reference' => '2cb48f26130919f92f30650bdcc30e6f4ebe45ac',
            'type' => 'library',
            'install_path' => __DIR__ . '/../paragonie/sodium_compat',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'php-debugbar/php-debugbar' => array(
            'pretty_version' => 'v2.2.6',
            'version' => '2.2.6.0',
            'reference' => 'abb9fa3c5c8dbe7efe03ddba56782917481de3e8',
            'type' => 'library',
            'install_path' => __DIR__ . '/../php-debugbar/php-debugbar',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'php-http/async-client-implementation' => array(
            'dev_requirement' => false,
            'provided' => array(
                0 => '*',
            ),
        ),
        'php-http/client-implementation' => array(
            'dev_requirement' => false,
            'provided' => array(
                0 => '*',
            ),
        ),
        'php-tuf/php-tuf' => array(
            'pretty_version' => '1.0.3',
            'version' => '1.0.3.0',
            'reference' => '1fc585dc5a090a4af94823e21470779f31030733',
            'type' => 'library',
            'install_path' => __DIR__ . '/../php-tuf/php-tuf',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'phpmailer/phpmailer' => array(
            'pretty_version' => 'v6.12.0',
            'version' => '6.12.0.0',
            'reference' => 'd1ac35d784bf9f5e61b424901d5a014967f15b12',
            'type' => 'library',
            'install_path' => __DIR__ . '/../phpmailer/phpmailer',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'phpseclib/bcmath_compat' => array(
            'pretty_version' => '2.0.3',
            'version' => '2.0.3.0',
            'reference' => 'ae8f87ea0c96b2ef08ecf0d291d45372d0f7bc5a',
            'type' => 'library',
            'install_path' => __DIR__ . '/../phpseclib/bcmath_compat',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'phpseclib/phpseclib' => array(
            'pretty_version' => '3.0.55',
            'version' => '3.0.55.0',
            'reference' => 'db9744e6d47e742b1f974e965ad49bdd041105af',
            'type' => 'library',
            'install_path' => __DIR__ . '/../phpseclib/phpseclib',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'psr/cache' => array(
            'pretty_version' => '3.0.0',
            'version' => '3.0.0.0',
            'reference' => 'aa5030cfa5405eccfdcb1083ce040c2cb8d253bf',
            'type' => 'library',
            'install_path' => __DIR__ . '/../psr/cache',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'psr/clock' => array(
            'pretty_version' => '1.0.0',
            'version' => '1.0.0.0',
            'reference' => 'e41a24703d4560fd0acb709162f73b8adfc3aa0d',
            'type' => 'library',
            'install_path' => __DIR__ . '/../psr/clock',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'psr/clock-implementation' => array(
            'dev_requirement' => false,
            'provided' => array(
                0 => '1.0',
            ),
        ),
        'psr/container' => array(
            'pretty_version' => '2.0.2',
            'version' => '2.0.2.0',
            'reference' => 'c71ecc56dfe541dbd90c5360474fbc405f8d5963',
            'type' => 'library',
            'install_path' => __DIR__ . '/../psr/container',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'psr/container-implementation' => array(
            'dev_requirement' => false,
            'provided' => array(
                0 => '~1.0',
            ),
        ),
        'psr/event-dispatcher' => array(
            'pretty_version' => '1.0.0',
            'version' => '1.0.0.0',
            'reference' => 'dbefd12671e8a14ec7f180cab83036ed26714bb0',
            'type' => 'library',
            'install_path' => __DIR__ . '/../psr/event-dispatcher',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'psr/http-client' => array(
            'pretty_version' => '1.0.3',
            'version' => '1.0.3.0',
            'reference' => 'bb5906edc1c324c9a05aa0873d40117941e5fa90',
            'type' => 'library',
            'install_path' => __DIR__ . '/../psr/http-client',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'psr/http-client-implementation' => array(
            'dev_requirement' => false,
            'provided' => array(
                0 => '1.0',
            ),
        ),
        'psr/http-factory' => array(
            'pretty_version' => '1.1.0',
            'version' => '1.1.0.0',
            'reference' => '2b4765fddfe3b508ac62f829e852b1501d3f6e8a',
            'type' => 'library',
            'install_path' => __DIR__ . '/../psr/http-factory',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'psr/http-factory-implementation' => array(
            'dev_requirement' => false,
            'provided' => array(
                0 => '1.0',
                1 => '^1.0',
            ),
        ),
        'psr/http-message' => array(
            'pretty_version' => '2.0',
            'version' => '2.0.0.0',
            'reference' => '402d35bcb92c70c026d1a6a9883f06b2ead23d71',
            'type' => 'library',
            'install_path' => __DIR__ . '/../psr/http-message',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'psr/http-message-implementation' => array(
            'dev_requirement' => false,
            'provided' => array(
                0 => '1.0',
                1 => '^1.1 || ^2.0',
            ),
        ),
        'psr/link' => array(
            'pretty_version' => '1.1.1',
            'version' => '1.1.1.0',
            'reference' => '846c25f58a1f02b93a00f2404e3626b6bf9b7807',
            'type' => 'library',
            'install_path' => __DIR__ . '/../psr/link',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'psr/link-implementation' => array(
            'dev_requirement' => false,
            'provided' => array(
                0 => '1.0',
                1 => '1.0|2.0',
            ),
        ),
        'psr/log' => array(
            'pretty_version' => '3.0.2',
            'version' => '3.0.2.0',
            'reference' => 'f16e1d5863e37f8d8c2a01719f5b34baa2b714d3',
            'type' => 'library',
            'install_path' => __DIR__ . '/../psr/log',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'psr/log-implementation' => array(
            'dev_requirement' => false,
            'provided' => array(
                0 => '1.0|2.0|3.0',
            ),
        ),
        'ralouphie/getallheaders' => array(
            'pretty_version' => '3.0.3',
            'version' => '3.0.3.0',
            'reference' => '120b605dfeb996808c31b6477290a714d356e822',
            'type' => 'library',
            'install_path' => __DIR__ . '/../ralouphie/getallheaders',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'spomky-labs/cbor-php' => array(
            'pretty_version' => '3.2.3',
            'version' => '3.2.3.0',
            'reference' => 'dd6eb84e6d92f7b8bd0da56b4b4dd7235aed0c32',
            'type' => 'library',
            'install_path' => __DIR__ . '/../spomky-labs/cbor-php',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'spomky-labs/pki-framework' => array(
            'pretty_version' => '1.4.2',
            'version' => '1.4.2.0',
            'reference' => 'aa576cbd07128075bef97ac2f8af9854e67513d8',
            'type' => 'library',
            'install_path' => __DIR__ . '/../spomky-labs/pki-framework',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/console' => array(
            'pretty_version' => 'v7.4.13',
            'version' => '7.4.13.0',
            'reference' => '85095d2573eaefaf35e40b9513a9bf09f72cd217',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/console',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/deprecation-contracts' => array(
            'pretty_version' => 'v3.7.0',
            'version' => '3.7.0.0',
            'reference' => '50f59d1f3ca46d41ac911f97a78626b6756af35b',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/deprecation-contracts',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/error-handler' => array(
            'pretty_version' => 'v7.4.8',
            'version' => '7.4.8.0',
            'reference' => '8dd79d8af777ee6cba2fd4d98da6ffb839f3c0fa',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/error-handler',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/http-client' => array(
            'pretty_version' => 'v7.4.13',
            'version' => '7.4.13.0',
            'reference' => 'e8a112b8415707265a7e614278136a9d92989a6a',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/http-client',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/http-client-contracts' => array(
            'pretty_version' => 'v3.7.0',
            'version' => '3.7.0.0',
            'reference' => '4a2d00c37651c0bdc2b9e1c773487a8bf4edb12d',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/http-client-contracts',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/http-client-implementation' => array(
            'dev_requirement' => false,
            'provided' => array(
                0 => '3.0',
            ),
        ),
        'symfony/ldap' => array(
            'pretty_version' => 'v7.4.10',
            'version' => '7.4.10.0',
            'reference' => 'bba9e535d29c15bd6842bf85bc341debfbb4bcb3',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/ldap',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/options-resolver' => array(
            'pretty_version' => 'v7.4.8',
            'version' => '7.4.8.0',
            'reference' => '2888fcdc4dc2fd5f7c7397be78631e8af12e02b4',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/options-resolver',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/polyfill-ctype' => array(
            'pretty_version' => 'v1.37.0',
            'version' => '1.37.0.0',
            'reference' => '141046a8f9477948ff284fa65be2095baafb94f2',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/polyfill-ctype',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/polyfill-intl-grapheme' => array(
            'pretty_version' => 'v1.38.1',
            'version' => '1.38.1.0',
            'reference' => 'e9247d281d694a5120554d9afaf54e070e88a603',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/polyfill-intl-grapheme',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/polyfill-intl-normalizer' => array(
            'pretty_version' => 'v1.38.0',
            'version' => '1.38.0.0',
            'reference' => '2d446c214bdbe5b71bde5011b060a05fece3ae6b',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/polyfill-intl-normalizer',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/polyfill-mbstring' => array(
            'pretty_version' => 'v1.38.2',
            'version' => '1.38.2.0',
            'reference' => 'd3d318bad5e7a1bfbd026009c8bfb8d8f99ae6b6',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/polyfill-mbstring',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/polyfill-php80' => array(
            'dev_requirement' => false,
            'replaced' => array(
                0 => '*',
            ),
        ),
        'symfony/polyfill-php81' => array(
            'dev_requirement' => false,
            'replaced' => array(
                0 => '*',
            ),
        ),
        'symfony/polyfill-php82' => array(
            'dev_requirement' => false,
            'replaced' => array(
                0 => '*',
            ),
        ),
        'symfony/polyfill-php83' => array(
            'dev_requirement' => false,
            'replaced' => array(
                0 => '*',
            ),
        ),
        'symfony/polyfill-php85' => array(
            'pretty_version' => 'v1.38.1',
            'version' => '1.38.1.0',
            'reference' => 'ba2ba04f3352cfa2dcbbcb90aee13ed967f505b1',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/polyfill-php85',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/polyfill-uuid' => array(
            'pretty_version' => 'v1.37.0',
            'version' => '1.37.0.0',
            'reference' => '26dfec253c4cf3e51b541b52ddf7e42cb0908e94',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/polyfill-uuid',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/service-contracts' => array(
            'pretty_version' => 'v3.7.0',
            'version' => '3.7.0.0',
            'reference' => 'd25d82433a80eba6aa0e6c24b61d7370d99e444a',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/service-contracts',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/string' => array(
            'pretty_version' => 'v7.4.13',
            'version' => '7.4.13.0',
            'reference' => '961683010db3b27ec6ebcd7308e6e1ee8fa7ffde',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/string',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/translation-contracts' => array(
            'pretty_version' => 'v3.7.0',
            'version' => '3.7.0.0',
            'reference' => '0ab302977a952b42fd51475c4ebac81f8da0a95d',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/translation-contracts',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/uid' => array(
            'pretty_version' => 'v6.4.32',
            'version' => '6.4.32.0',
            'reference' => '6b973c385f00341b246f697d82dc01a09107acdd',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/uid',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/validator' => array(
            'pretty_version' => 'v6.4.37',
            'version' => '6.4.37.0',
            'reference' => '72cfcf7925746d9950bbdab1362f6bda3b4046cf',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/validator',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/var-dumper' => array(
            'pretty_version' => 'v7.4.8',
            'version' => '7.4.8.0',
            'reference' => '9510c3966f749a1d1ff0059e1eabef6cc621e7fd',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/var-dumper',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/web-link' => array(
            'pretty_version' => 'v6.4.32',
            'version' => '6.4.32.0',
            'reference' => '636d5e34cd5c4a2538b02ba48a3c02989bfdf06b',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/web-link',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/yaml' => array(
            'pretty_version' => 'v6.4.41',
            'version' => '6.4.41.0',
            'reference' => 'e8fdf3408c85806198d5826e604ffc6830d33152',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/yaml',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'tobscure/json-api' => array(
            'pretty_version' => 'dev-joomla-backports',
            'version' => 'dev-joomla-backports',
            'reference' => '6ce73102280c9c70b41e3407d2504279fa07d158',
            'type' => 'library',
            'install_path' => __DIR__ . '/../tobscure/json-api',
            'aliases' => array(
                0 => '9999999-dev',
            ),
            'dev_requirement' => false,
        ),
        'wamania/php-stemmer' => array(
            'pretty_version' => 'v4.0.0',
            'version' => '4.0.0.0',
            'reference' => 'd96509294ea843b4b86e4900df27424a6ea0ace8',
            'type' => 'library',
            'install_path' => __DIR__ . '/../wamania/php-stemmer',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'web-auth/cose-lib' => array(
            'pretty_version' => '4.5.2',
            'version' => '4.5.2.0',
            'reference' => '5b38660f90070a8e45f3dbc9528ade3b608dd77d',
            'type' => 'library',
            'install_path' => __DIR__ . '/../web-auth/cose-lib',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'web-auth/metadata-service' => array(
            'pretty_version' => '4.5.2',
            'version' => '4.5.2.0',
            'reference' => '82b3a517894987db1f8959a9320b9891515af9e7',
            'type' => 'library',
            'install_path' => __DIR__ . '/../web-auth/metadata-service',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'web-auth/webauthn-lib' => array(
            'pretty_version' => '4.5.2',
            'version' => '4.5.2.0',
            'reference' => '30c5e891c6418abef6d87a4351132b01b1828a98',
            'type' => 'library',
            'install_path' => __DIR__ . '/../web-auth/webauthn-lib',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'web-token/jwt-library' => array(
            'pretty_version' => '3.4.10',
            'version' => '3.4.10.0',
            'reference' => '8c38010d971c2313406fa1376d763cee745a833b',
            'type' => 'library',
            'install_path' => __DIR__ . '/../web-token/jwt-library',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'willdurand/negotiation' => array(
            'pretty_version' => '3.1.0',
            'version' => '3.1.0.0',
            'reference' => '68e9ea0553ef6e2ee8db5c1d98829f111e623ec2',
            'type' => 'library',
            'install_path' => __DIR__ . '/../willdurand/negotiation',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
    ),
);
