<?php

/**
 * @package     Joomla.Administrator
 * @subpackage  com_workflow
 *
 * @copyright   (C) 2026 Open Source Matters, Inc. <https://www.joomla.org>
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 * @since       6.1.0
 */

use Joomla\CMS\Language\Text;

// phpcs:disable PSR1.Files.SideEffects
\defined('_JEXEC') or die;
// phpcs:enable PSR1.Files.SideEffects

// Populate the language
$translationStrings = [
    'COM_WORKFLOW_GRAPH',
    'COM_WORKFLOW_GRAPH_ADD_STAGE',
    'COM_WORKFLOW_GRAPH_ADD_STAGE_DIALOG_OPENED',
    'COM_WORKFLOW_GRAPH_ADD_TRANSITION_DIALOG_OPENED',
    'COM_WORKFLOW_GRAPH_ADD_TRANSITION',
    'COM_WORKFLOW_GRAPH_API_NOT_SET',
    'COM_WORKFLOW_GRAPH_BACKGROUND',
    'COM_WORKFLOW_GRAPH_CANVAS_DESCRIPTION',
    'COM_WORKFLOW_GRAPH_CANVAS_LABEL',
    'COM_WORKFLOW_GRAPH_CANVAS_VIEW_CONTROLS',
    'COM_WORKFLOW_GRAPH_CLEAR_SELECTION',
    'COM_WORKFLOW_GRAPH_CLOSE_ACTIONS_MENU',
    'COM_WORKFLOW_GRAPH_CONTROLS',
    'COM_WORKFLOW_GRAPH_CREATING_TRANSITION',
    'COM_WORKFLOW_GRAPH_DEFAULT',
    'COM_WORKFLOW_GRAPH_DISABLED',
    'COM_WORKFLOW_GRAPH_EDIT_ITEM',
    'COM_WORKFLOW_GRAPH_EDIT_STAGE',
    'COM_WORKFLOW_GRAPH_EDIT_TRANSITION',
    'COM_WORKFLOW_GRAPH_ENABLED',
    'COM_WORKFLOW_GRAPH_ERROR_CSRF_TOKEN_NOT_SET',
    'COM_WORKFLOW_GRAPH_ERROR_EXTENSION_NOT_SET',
    'COM_WORKFLOW_GRAPH_ERROR_FAILED_TO_UPDATE_STAGE_POSITIONS',
    'COM_WORKFLOW_GRAPH_ERROR_FETCHING_MODEL',
    'COM_WORKFLOW_GRAPH_ERROR_INVALID_ID',
    'COM_WORKFLOW_GRAPH_ERROR_INVALID_POSITION_DATA',
    'COM_WORKFLOW_GRAPH_ERROR_INVALID_STAGE_POSITIONS',
    'COM_WORKFLOW_GRAPH_ERROR_STAGES_NOT_FOUND',
    'COM_WORKFLOW_GRAPH_ERROR_STAGE_DEFAULT_CANT_DELETED',
    'COM_WORKFLOW_GRAPH_ERROR_STAGE_HAS_TRANSITIONS',
    'COM_WORKFLOW_GRAPH_ERROR_UNKNOWN',
    'COM_WORKFLOW_GRAPH_ERROR_WORKFLOW_ID_NOT_SET',
    'COM_WORKFLOW_GRAPH_ERROR_WORKFLOW_NOT_FOUND',
    'COM_WORKFLOW_GRAPH_FIT_VIEW',
    'COM_WORKFLOW_GRAPH_FOCUS_TYPE_CHANGE',
    'COM_WORKFLOW_GRAPH_FROM_ANY',
    'COM_WORKFLOW_GRAPH_LOADING',
    'COM_WORKFLOW_GRAPH_MINIMAP_HIDE',
    'COM_WORKFLOW_GRAPH_MINIMAP_LABEL',
    'COM_WORKFLOW_GRAPH_MINIMAP_SHOW',
    'COM_WORKFLOW_GRAPH_MOVE_STAGE',
    'COM_WORKFLOW_GRAPH_MOVE_VIEW',
    'COM_WORKFLOW_GRAPH_NAVIGATE_NODES',
    'COM_WORKFLOW_GRAPH_OPEN_ACTIONS_MENU',
    'COM_WORKFLOW_GRAPH_SELECTION_CLEARED',
    'COM_WORKFLOW_GRAPH_SELECT_ITEM',
    'COM_WORKFLOW_GRAPH_SHORTCUTS',
    'COM_WORKFLOW_GRAPH_SHORTCUTS_TITLE',
    'COM_WORKFLOW_GRAPH_STAGE',
    'COM_WORKFLOW_GRAPH_STAGES',
    'COM_WORKFLOW_GRAPH_STAGE_ACTIONS',
    'COM_WORKFLOW_GRAPH_STAGE_COUNT',
    'COM_WORKFLOW_GRAPH_STAGE_DEFAULT',
    'COM_WORKFLOW_GRAPH_STAGE_DESCRIPTION',
    'COM_WORKFLOW_GRAPH_STAGE_POSITIONS_UPDATED',
    'COM_WORKFLOW_GRAPH_STAGE_REF',
    'COM_WORKFLOW_GRAPH_STAGE_SELECTED',
    'COM_WORKFLOW_GRAPH_STAGE_STATUS_ENABLED',
    'COM_WORKFLOW_GRAPH_STAGE_STATUS_DISABLED',
    'COM_WORKFLOW_GRAPH_STATUS',
    'COM_WORKFLOW_GRAPH_TRANSITION',
    'COM_WORKFLOW_GRAPH_TRANSITIONS',
    'COM_WORKFLOW_GRAPH_TRANSITION_ACTIONS',
    'COM_WORKFLOW_GRAPH_TRANSITION_COUNT',
    'COM_WORKFLOW_GRAPH_TRANSITION_DESCRIPTION',
    'COM_WORKFLOW_GRAPH_TRANSITION_PATH',
    'COM_WORKFLOW_GRAPH_TRANSITION_REF',
    'COM_WORKFLOW_GRAPH_TRANSITION_SELECTED',
    'COM_WORKFLOW_GRAPH_TRANSITION_STATUS_ENABLED',
    'COM_WORKFLOW_GRAPH_TRANSITION_STATUS_DISABLED',
    'COM_WORKFLOW_GRAPH_TRASH_ITEM',
    'COM_WORKFLOW_GRAPH_TRASH_STAGE',
    'COM_WORKFLOW_GRAPH_TRASH_STAGE_CONFIRM',
    'COM_WORKFLOW_GRAPH_TRASH_STAGE_FAILED',
    'COM_WORKFLOW_GRAPH_TRASH_TRANSITION',
    'COM_WORKFLOW_GRAPH_TRASH_TRANSITION_CONFIRM',
    'COM_WORKFLOW_GRAPH_TRASH_TRANSITION_FAILED',
    'COM_WORKFLOW_GRAPH_UNSAVED_CHANGES',
    'COM_WORKFLOW_GRAPH_UPDATE_STAGE_POSITION_FAILED',
    'COM_WORKFLOW_GRAPH_UP_TO_DATE',
    'COM_WORKFLOW_GRAPH_WORKFLOWS_EDIT',
    'COM_WORKFLOW_GRAPH_ZOOM_IN',
    'COM_WORKFLOW_GRAPH_ZOOM_OUT',
    'JNO',
    'JYES',
];

foreach ($translationStrings as $string) {
    Text::script($string);
}
