@font-face {
    font-family: 'Roboto-Slab';
    src: url('../../fonts/roboto-slab/Roboto-Slab-Thin.woff2') format('woff2'), url('../../fonts/roboto-slab/Roboto-Slab-Thin.woff') format('woff');
    font-weight: 100;
    font-style: normal;
}

@font-face {
    font-family: 'Roboto-Slab-Thin';
    src: url('../../fonts/roboto-slab/Roboto-Slab-Thin.woff2') format('woff2'), url('../../fonts/roboto-slab/Roboto-Slab-Thin.woff') format('woff');
}

@font-face {
    font-family: 'Roboto-Slab';
    src: url('../../fonts/roboto-slab/Roboto-Slab-Light.woff2') format('woff2'), url('../../fonts/roboto-slab/Roboto-Slab-Light.woff') format('woff');
    font-weight: 300;
    font-style: normal;
}

@font-face {
    font-family: 'Roboto-Slab-Light';
    src: url('../../fonts/roboto-slab/Roboto-Slab-Light.woff2') format('woff2'), url('../../fonts/roboto-slab/Roboto-Slab-Light.woff') format('woff');
}

@font-face {
    font-family: 'Roboto-Slab';
    src: url('../../fonts/roboto-slab/Roboto-Slab-Regular.woff2') format('woff2'), url('../../fonts/roboto-slab/Roboto-Slab-Regular.woff') format('woff');
    font-weight: 400;
    font-style: normal;
}

@font-face {
    font-family: 'Roboto-Slab-Regular';
    src: url('../../fonts/roboto-slab/Roboto-Slab-Regular.woff2') format('woff2'), url('../../fonts/roboto-slab/Roboto-Slab-Regular.woff') format('woff');
}

@font-face {
    font-family: 'Roboto-Slab';
    src: url('../../fonts/roboto-slab/Roboto-Slab-Bold.woff2') format('woff2'), url('../../fonts/roboto-slab/Roboto-Slab-Bold.woff') format('woff');
    font-weight: 700;
    font-style: normal;
}

@font-face {
    font-family: 'Roboto-Slab-Bold';
    src: url('../../fonts/roboto-slab/Roboto-Slab-Bold.woff2') format('woff2'), url('../../fonts/roboto-slab/Roboto-Slab-Bold.woff') format('woff');
}
